# doas

## Description

Manager doas.conf(5) rulesets on OpenBSD.
Strong types, stable configuration order and validation help avoiding mistakes.

## Usage

Ensure the configuration file to be absent in case no rules are defined:
```
include doas
```

Permit the developer's group to deploy tests without flexibility:
```
doas::rule { 'deploy':
  identity => ':dev',
  target   => '_push',
  cmd      => '/usr/local/bin/deploy',
  args     => [
    '--testing',
  ],
}
```

Grant the admin group passwordless access to all users and programs:
```
doas::rule { 'admins':
  identity => ':wheel',
  nopass   => true,
}
```

Permit user to run script as root, e.g. `doas /usr/local/bin/script`:
```
doas::rule { 'script':
  identity => 'kn',
  target   => 'root',
  cmd      => '/usr/local/bin/script',
}
```  

Permit admin to configure the network, but in dry-run, i.e. `doas /bin/sh /etc/netstart -n`:
```
doas::rule { 'netstart':
  identity => ':wheel',
  target   => 'root',
  cmd      => '/usr/local/bin/script',
}
```  

## Limitations

This module is written for and tested on OpenBSD.

## Development

Feedback and diffs are always welcome.
