# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`doas`](#doas): Manage doas.conf(5)

### Defined types

* [`doas::rule`](#doasrule): Individual doas.conf(5) rule

### Data types

* [`Doas::Identity`](#doasidentity)
* [`Doas::Target`](#doastarget)

## Classes

### `doas`

Maintain uniform and validated doas(1) rulesets

#### Examples

##### 

```puppet
include doas
```

#### Parameters

The following parameters are available in the `doas` class.

##### `config_file`

Data type: `Stdlib::Unixpath`

The configuration file to be managed

Default value: `'/etc/doas.conf'`

##### `rules`

Data type: `Optional[Hash]`

Individual rules

Default value: ``undef``

## Defined types

### `doas::rule`

Generate a single line for doas

#### Examples

##### 

```puppet
doas::rule { 'everything goes for wheel':
  nopass   => true,
  keepenv  => true,
  setenv   => [
    'HOME',
  ],
  identity => ':wheel',
}
```

#### Parameters

The following parameters are available in the `doas::rule` defined type.

##### `order`

Data type: `Variant[String,Integer]`

Alphanumerical key to sort this rule in the file

Default value: `$title`

##### `action`

Data type: `Enum['permit','deny']`

The action to be taken if this rule matches

Default value: `'permit'`

##### `nopass`

Data type: `Boolean`

Whether the user is required to enter a password

Default value: ``false``

##### `nolog`

Data type: `Boolean`

Whether successful command execution is logged to syslogd(8)

Default value: ``false``

##### `persist`

Data type: `Boolean`

Whether successful authentication persists for some time

Default value: ``false``

##### `keepenv`

Data type: `Boolean`

Whether environment variables are retained for the new process

Default value: ``false``

##### `setenv`

Data type: `Optional[Array[String[1],1]]`

List of variables to set or remove

Default value: ``undef``

##### `identity`

Data type: `Doas::Identity`

Running user- or groupname to match

Default value: `$title`

##### `target`

Data type: `Optional[Doas::Target]`

Target user allowed or denied to run as

Default value: ``undef``

##### `cmd`

Data type: `Optional[Stdlib::Unixpath]`

Command allowed or denied to run

Default value: ``undef``

##### `args`

Data type: `Optional[Array[String]]`

Exact command arguments

Default value: ``undef``

## Data types

### `Doas::Identity`

The Doas::Identity data type.

Alias of `Pattern[/^:?[a-zA-Z0-9._][a-zA-Z0-9._-]{1,30}\$?$/]`

### `Doas::Target`

The Doas::Target data type.

Alias of `Pattern[/^[a-zA-Z0-9._][a-zA-Z0-9._-]{1,30}\$?$/]`

