# @summary Manage doas.conf(5)
#
# Maintain uniform and validated doas(1) rulesets
#
# @param config_file
#  The configuration file to be managed
#
# @param rules
#  Individual rules
#
# @example
#   include doas
class doas (
  Stdlib::Unixpath $config_file = '/etc/doas.conf',
  Optional[Hash]   $rules       = undef,
) {
  concat { $config_file:
    # match /etc/examples/doas.conf
    owner             => 'root',
    group             => 'wheel',
    mode              => '0600',
    order             => 'alpha',
    # one rule per line
    ensure_newline    => true,
    # ensure file is removed if empty
    create_empty_file => false,
    # fail on invalid configuration
    validate_cmd      => '/usr/bin/doas -C % --',
  }

  if $rules {
    ensure_resources('doas::rule', $rules)
  }
}
